@@ -96,7 +96,7 @@ class Incantation:
             'description': self.description
         }
         resp = _format_http_response(requests.post(url, headers=HEADERS, json=payload))
-        self.incantation_id = self.get_incantation_id()
+        self.incantation_id = resp['body']['id']
         self.is_deployed = True
         incantations[resp['body']['id']]
         return resp['body']
